UNIT uBatterie;
(* ******************************************************************** *)
(* K L A S S E : TBatterie                                              *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.3.2                                                  *)
(* Autor       : S. Spolwig, 2005                                       *)
(* Beschreibung: Die Klasse abstrahiert und modelliert eine Batterie    *)
(*               mit 1.5 V, 1.200 mAh                                   *)
(* Aenderungen : V. 1.3.2 - 01-OKT-5    Spannung sinkt nach OHM         *)
(* ******************************************************************** *)

INTERFACE
// =======================================================================

type
  TBatterie = class(TObject)
   private
    Spannung : double;              // eff. Spannung
    Ri       : double;              // Innenwiderstand

   public
    constructor Create;
    function    GetSpannung (RLast : double) : double;
  end;

(* -------------------- B e s c h r e i b u n g -------------------------

Oberklasse    : -
Bezugsklassen :      import:


Methoden
--------
Create
  Auftrag: Erzeugen und initialisieren
  vorher :
  nachher: Spannung ist 1.5 V, Innenwiderstand ist 0

GetSpannung ()
  Anfrage: nach der aktuellen Spannung unter Belastung;
  vorher : Batt. ist init.
  nachher: Innenwiderstand ist erhoeht, Spannung vermindert

--------------------------------------------------------------------- *)


IMPLEMENTATION
// ====================================================================

constructor TBatterie.Create;
// --------------------------------------------------------------------
begin
  inherited Create;
  Spannung := 1.5;
  Ri       :=   0;
end;


function TBatterie.GetSpannung (RLast : double) : double;
// --------------------------------------------------------------------
var                                      // weglassen????
  U,          // Spannung in Volt
  I,          // Strom in Amp
  UL : double;  // LastSpannung; neue Spannung an der Lampe

begin
   U  := Spannung;

   Ri := Ri + 0.001;      // der Innenwiderstand der realen Spannungsquelle steigt
   I  := U /(Ri + RLast); // der Strom sinkt
   UL := I * RLast;       // die Spannung unter Last an der Lampe sinkt

   Spannung := UL;
   Result := Spannung;
end;


END. // -------- UNIT -------------
