UNIT uGluehlampe;
(* ******************************************************************** *)
(* K L A S S E : TGluehlampe                                            *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.3.2                                                  *)
(* Autor       : S. Spolwig, 2005                                       *)
(* Beschreibung: Die Klasse abstrahiert und modelliert eine Lampe 4.5 V,*)
(*               300 mA                                                 *)
(*                                                                      *)
(* Compiler    : Delphi 6.0                                             *)
(* Aenderungen : V. 1.3.2 - 01-OKT-05   GetWiderstand                   *)
(* ******************************************************************** *)

INTERFACE
// =======================================================================
uses uLampe;

type
  TGluehlampe = class(TLampe)
   private
    Nennspannung,
    Spannung  : double;   // eff. anliegende Sp.
    Widerstand: double;
   public
    constructor Create;
    procedure   SetSpannung (u : double);
    function    GetSpannung : double;     // prfen, ob Saft da ist
    function    GetHelligkeit : integer;
    function    GetWiderstand : double;
  end;

(* -------------------- B e s c h r e i b u n g -------------------------

Oberklasse    : TLampe
Bezugsklassen : -     import:


Methoden
--------

SetSpannung
  Auftrag: Lampe mit Strom versorgen und leuchten lassen
  vorher : -
  nachher: Leuchtet oder nicht

Get...
  Auftrag: Attribut aus dem Objekt lesen
  vorher : Objekt ist init.
  nachher: -

GetHelligkeit : integer;
  Anfrage: nach prozentualem Stand der Spannung = Helligkeitsfaktor
  vorher :
  nachher:  hell, wenn 100%;

--------------------------------------------------------------------- *)

IMPLEMENTATION
// ====================================================================

constructor TGluehlampe.Create;
// --------------------------------------------------------------------
begin
  inherited Create;
  Nennspannung := 4.5;
  Spannung     := 0;
  Widerstand   := 15;       // R = U/I
end;


procedure TGluehlampe.SetSpannung (u : double);
// --------------------------------------------------------------------
begin
  Spannung := u;
  if Spannung > 0
  then Leuchten;
end;


function TGluehlampe.GetSpannung : double;
// --------------------------------------------------------------------
begin
  Result := Spannung;
end;


function TGluehlampe.GetHelligkeit : integer;
// --------------------------------------------------------------------
begin
   Result := Round(Spannung / Nennspannung * 100);  // 100 % = hell
   if Result <= 0
   then Result := 1;
end;


function TGluehlampe.GetWiderstand : double;
// --------------------------------------------------------------------
begin
  Result := Widerstand;
end;

END. // -------- UNIT -------------
