UNIT uTaschenlampe;
(* ******************************************************************** *)
(* K L A S S E : TTaschenlampe                                          *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.3.2                                                  *)
(* Autor       : S. Spolwig, 2005                                       *)
(* Beschreibung: Die Klasse abstrahiert und modelliert eine Taschenlampe*)
(*               mit einer diskreten Gluehlampe und 3 x 1.5 V Batterien.*)
(*                                                                      *)
(* Compiler    : Delphi 6.0                                             *)
(* Aenderungen : V. 1.2   - 01-OKT-05   TGluehlampe, TBatterie          *)
(*                  1.3 -               abnehmende Helligkeit           *)
(*                  1.3.2               OHM                             *)
(* ******************************************************************** *)

INTERFACE
// =======================================================================

uses uGluehLampe, uBatterie;

type
  TTaschenlampe = class(TObject)
   private
    Lampe     : TGluehLampe;
    Batterie1,
    Batterie2,
    Batterie3 : TBatterie;
    Schalter  : boolean;

   public
    constructor Create;
    procedure Einschalten;
    procedure Ausschalten;
    function  Leuchtet : boolean;
    function  GetHelligkeit : integer;
  end;

(* -------------------- B e s c h r e i b u n g -------------------------

Oberklasse    :
Bezugsklassen : ...........      import:


Methoden
--------
Einschalten
  Auftrag: TL einschalten
  vorher : -
  nacher : Schalter true; Lampe bekommt Spannung von Batt.

Ausschalten
  Auftrag: TL ausschalten
  vorher : -
  nacher : Schalter false; Lampe bekommt Spannung 0.

GetHelligkeit
  Anfrage: nach der aktuellen Helligkeit der Lampe, Spannung sinken lassen,
           neue Spannung an Lampe
  vorher : -
  nachher: done

Leuchtet
  Anfrage: ob die Taschenlampe 'brennt'
  vorher :
  nachher: leuchtet, wenn Lampe Licht gibt und Batteriespannnung > 0 und Schalter auf EIN
           wenn true, Battriespannung sinkt und Lampe hat neue Spannung


--------------------------------------------------------------------- *)


IMPLEMENTATION
// ====================================================================

constructor TTaschenlampe.Create;
// --------------------------------------------------------------------
begin
  inherited Create;
  Lampe     := TGluehLampe.Create;
  Batterie1 := TBatterie.Create;   // 3 Batt. einbauen!
  Schalter  := false               // aus
end;


procedure TTaschenlampe.Einschalten;
// --------------------------------------------------------------------
var U : double;

begin
  Schalter := true;
  U := Batterie1.GetSpannung (15); //+ Batterie2.GetSpannung + Batterie3.GetSpannung;
  Lampe.SetSpannung(U);
end;


procedure TTaschenlampe.Ausschalten;
// --------------------------------------------------------------------
begin
  Schalter := false;
  Lampe.SetSpannung(0); 
end;


function TTaschenlampe.Leuchtet : boolean;
// --------------------------------------------------------------------
var
  RL : double;         // Lastwiderstand der Lampe in Ohm

begin
  Result := (Lampe.GetLicht = true) AND (Lampe.GetSpannung > 0) AND (Schalter = true);
  if true
  then
    begin
      RL := Lampe.GetWiderstand;
      Lampe.SetSpannung(Batterie1.GetSpannung(RL));
    end;
end;


function  TTaschenlampe.GetHelligkeit : integer;
// --------------------------------------------------------------------
begin
  Result := Lampe.GetHelligkeit;
end;                                  


END. // -------- UNIT -------------
