UNIT uTaschenlampe;
(* ******************************************************************** *)
(* K L A S S E : TTaschenlampe                                          *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.3                                                    *)
(* Autor       : S. Spolwig, 2005                                       *)
(* Beschreibung: Die Klasse abstrahiert und modelliert eine Taschenlampe*)
(*               mit einer diskreten Gluehlampe und 3 x 1.5 V Batterien.*)
(*                                                                      *)
(* Compiler    : Delphi 6.0                                             *)
(* Aenderungen : V. 1.2   - 01-OKT-05   TGluehlampe, TBatterie          *)
(*                  1.3                 abnehmende Helligkeit durch     *)
(*                                      Reduzierung der Spannung        *)
(* ******************************************************************** *)

INTERFACE
// =======================================================================

uses uGluehLampe, uBatterie;

type
  TTaschenlampe = class(TObject)
   private
    Lampe     : TGluehLampe;
    Batterie1,
    Batterie2,
    Batterie3 : TBatterie;
    Schalter  : boolean;

   public
    constructor Create;
    procedure   Einschalten;
    procedure   Ausschalten;
    function    Leuchtet : boolean;   
    function    GetHelligkeit : integer;
  end;

(* -------------------- B e s c h r e i b u n g -------------------------

Oberklasse    :
Bezugsklassen : TBatterie, TGluehlampe     import:


Methoden
--------
Einschalten
  Auftrag: Schalter auf ein und Lampe mit Batteriespannung versorgen
  vorher :
  nachher: done

Ausschalten
  Auftrag: Schalter auf aus und Spannung an der Lampe auf 0
  vorher :
  nachher: done

GetHelligkeit
  Anfrage: nach der aktuellen Helligkeit der Lampe, Spannung sinken lassen,
           neue Spannung an Lampe
  vorher : -
  nachher: done

Leuchtet
  Anfrage: ob die Taschenlampe 'brennt'
  vorher :
  nachher: leuchtet, wenn Lampe Licht gibt und Batteriespannnung > 0 und Schalter auf EIN.
           Lampe bekommt aktuelle Batteriespannung

--------------------------------------------------------------------- *)


IMPLEMENTATION
// ====================================================================

constructor TTaschenlampe.Create;
// --------------------------------------------------------------------
begin
  inherited Create;
  Lampe     := TGluehLampe.Create;
  Batterie1 := TBatterie.Create;   // 3 Batt. einbauen
//  Batterie2 := TBatterie.Create;
//  Batterie3 := TBatterie.Create;
  Schalter  := false // aus
end;


procedure TTaschenlampe.Einschalten;
// --------------------------------------------------------------------
var U : double;

begin
  Schalter := true;
  U := Batterie1.GetSpannung; //+ Batterie2.GetSpannung + Batterie3.GetSpannung;
  Lampe.SetSpannung(U);
end;


procedure TTaschenlampe.Ausschalten;
// --------------------------------------------------------------------
begin
  Schalter := false;
  Lampe.SetSpannung(0); 
end;


function TTaschenlampe.Leuchtet : boolean;
// --------------------------------------------------------------------
begin
  Lampe.SetSpannung(Batterie1.GetSpannung);
  Result := (Lampe.GetLicht = true) AND (Batterie1.GetSpannung > 0) AND (Schalter = true);
end;


function  TTaschenlampe.GetHelligkeit : integer;
// --------------------------------------------------------------------
begin
  Result := Lampe.GetHelligkeit;  // Aufruf durchreichen
end;

END. // -------- UNIT -------------
